cubicweb.timeline-ext.js — CubicWeb 3.13.2

### Navigation

- index
- modules |
- next |
- previous |
- CubicWeb 3.13.2 »
- Web side development »
- Javascript »
- <no title> »

# cubicweb.timeline-ext.js

organization: | Logilab :copyright: 2008-2010 LOGILAB S.A. (Paris, FRANCE), all rights reserved. :contact: http://www.logilab.fr/ – mailto:contact@logilab.fr

provide our own custom date parser since the default one only understands iso8601 and gregorian dates

CUBICWEB EVENT PAINTER ************************************************

### Navigation

- index
- modules |
- next |
- previous |
- CubicWeb 3.13.2 »
- Web side development »
- Javascript »
- <no title> »